#!/usr/bin/env Rscript

library(data.table)
library(dplyr)

csv_dir <- "/esarchive/scratch/acantare/Unica360_analysis/results"

# Get list of CSV files
csv_files <- list.files(path = csv_dir,
                        pattern = "*.csv",
                        full.names = TRUE)

# Read and combine all CSVs
combined_data <- rbindlist(
  lapply(csv_files, function(file) {
    # Read each file
    df <- fread(file)
    # Add file name as a column
    df$source_file <- basename(file)
    return(df)
  }),
  fill = TRUE  # Handles the case of different columns between files
)

# Save the result
output_file <- "combined_catalunya.csv"
fwrite(combined_data, output_file)

# Print summary
cat("Combined files:", length(csv_files), "\n")
cat("Total rows:", nrow(combined_data), "\n")
cat("Total columns:", ncol(combined_data), "\n")
cat("Result saved in:", output_file, "\n")