
library(sf)
library(mapview)
library(RColorBrewer)
library(htmlwidgets)
 
generate_map <- function(data, zcol, breaks, folder = "exploratory_maps") {

  
  # Convert data to sf object
  sf_data <- st_as_sf(data, wkt = "geom", crs = 4326)
  
  # Create a color palette
  num_colors <- length(breaks) - 1  # Number of breaks minus 1
  colors <- c(RColorBrewer::brewer.pal(min(num_colors, 9), "Blues"), "red")
  
  # Create the map
  m <- mapview(sf_data, zcol = zcol, at = breaks, col.regions = colors)
  
  # Ensure the folder exists
  if (!dir.exists(folder)) {
    dir.create(folder, recursive = TRUE)
  }
  
  # Save the map
  mapshot(m, file.path(folder, paste0(zcol, ".html")), selfcontained = FALSE)
}




var_breaks_list <- list(
  p_t = c(0, 10, 20, 30, 40, 50, 100, 500, 1000, Inf),
  hog = c(0, 2.5, 5, 7.5, 10, 20, 30, 100, 200, Inf),
  p_ed_00_04_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_04_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_14_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_15_24_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_25_44_h = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 100, 150, Inf),
  p_ed_45_64_h = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_65_79_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 50, Inf),
  p_ed_80_mas_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_14_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_15_24_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_25_44_m = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_45_64_m = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_65_79_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_80_mas_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  inm_pobr = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 150, 300, Inf),
  renta_tit_disp = c(0, 10000, 15000, 20000, 25000, 30000, 35000, 40000, 50000, Inf),
  salario_act = c(0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, Inf)
)



# Catalunya maps

for (var in names(var_breaks_list)) {
  generate_map(sf_bcn_socioPollution, var, var_breaks_list[[var]])
  print(paste("Map generated for", var))
}


#--------

# Barcelona maps (joined with pollution)

for (var in names(var_breaks_list)) {
  generate_map(sf_bcn_socioPollution, var, var_breaks_list[[var]], 'exploratory_maps_BCN')
  print(paste("Map generated for", var))
}



# Pollution map without breaks ----------------
m <- mapview(sf_bcn_socioPollution, zcol = 'mean_pollutant')
mapshot(m, file.path('exploratory_maps_BCN', paste0('mean_pollutant', ".html")), selfcontained = FALSE)




